@@ -1,6 +1,8 @@
 import os
 import time
 
+STRFTIME_SHORT = "%Y-%m-%d.%H-%M"
+STRFTIME_LONG = "%Y-%m-%d.%H-%M-%S"
 LOGGING_FORMATTER_KWARGS = dict(fmt='%(asctime)-25s %(levelname)-8s %(name)-50s %(message)s',
                                 datefmt='%Y-%m-%d %H:%M:%S %z')
 
@@ -11,7 +13,7 @@ def get_logs_directory():
         return os.path.join(os.path.sep, 'var', 'log')
 
 def get_timestamp(seconds=False):
-    return time.strftime("%Y-%m-%d.%H-%M-%S" if seconds else "%Y-%m-%d.%H-%M")
+    return time.strftime(STRFTIME_LONG if seconds else STRFTIME_SHORT)
 
 def get_platform_name(): # pragma: no cover
     from platform import system
